@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20230630';
+our $VERSION = '0.20230731';
 
-# Table last modified: 2023-06-30
+# Table last modified: 2023-07-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -13,7 +13,7 @@ our %ZIP_TABLE = (
     '004' => '(?:8(?:5(?:[67]7|23|0[23]|1[028]|[58][58]|3[0-3])|6(?:[34]1|[68]6|29|0[23]|1[0-368])))',
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[58]5|61)|612))',
-    '007' => '(?:8(?:5(?:53|85|0[13578])|632|733))',
+    '007' => '(?:8(?:5(?:11|53|85|0[13578])|632|733))',
     '010' => '(?:(?:8(?:5(?:43|3[03]|2[05]|1[158]|6[045]|[58][08]|0[124-7]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[23]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
@@ -104,11 +104,11 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:4(?:7[05-7]|1[0568]|6[0-246]|4[14-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|1[01358]|8[38]|0[178]|5[013-589]|4[367]|3[3568]|2[3-69]|7[258])|9(?:01|50|7[0-37]|4[16]|8[36])|7(?:0[137]|1[0-25-8])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
+    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|8[38]|0[178]|5[013-589]|4[367]|3[3568]|1[0138]|2[3-69]|7[258])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|1[0-258]|5[124578]|0[568]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
+    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|5(?:1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
@@ -130,7 +130,7 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|0[14689]|[24][17]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|6[168]|5[1-38]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
-    '231' => '(?:8(?:5(?:04|6[26]|8[58]|3[0469]|2[08]|4[49]|5[035])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|6(?:16|23|31|60|5[124]|8[29])|4(?:[368]4|45|7[78]|1[19])|7(?:50|7[12]|1[15])|00[18]|831|966))',
+    '231' => '(?:8(?:5(?:04|6[26]|8[58]|3[0469]|2[08]|4[49]|5[035])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|4(?:[368]4|[45]5|7[78]|1[19])|6(?:16|23|31|60|5[124]|8[29])|7(?:50|7[12]|1[15])|00[18]|831|966))',
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
@@ -231,7 +231,7 @@ our %ZIP_TABLE = (
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
     '251' => '(?:8(?:5(?:22|70|4[03]|8[018]|5[0158]|3[0134]|1[0135]|6[067]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[05-8]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[05-8]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
-    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:9[258]|8[05689])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
+    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[035689]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
     '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -738,7 +738,7 @@ our %ZIP_TABLE = (
     '777' => '(?:(?:0395|8577))',
     '778' => '(?:(?:850[13-7]|0[12]95))',
     '779' => '(?:(?:3(?:39[3-5]|[4-6]95|29[58])|4(?:[478]95|19[35])|1(?:29[235]|195)|(?:53|2[13])95|019[2-5]))',
-    '780' => '(?:8(?:5(?:3[024-69]|0[1-47-9]|4[0145]|5[03-589]|1[024-7]|2[0278]|6[125-8]|7[0-27])|6(?:86|7[067]|0[125]|6[0-3568])|787))',
+    '780' => '(?:8(?:5(?:3[024-69]|0[1-47-9]|4[0145]|5[03-589]|1[024-7]|2[0278]|6[125-8]|7[0-27])|6(?:86|7[067]|0[125]|6[013568])|787))',
     '781' => '(?:(?:9(?:5(?:[05]6|48|3[378]|2[569]|1[139])|68[3-9])|85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
     '783' => '(?:85(?:[58]5|0[125-9]|1[01]))',
@@ -818,9 +818,9 @@ our %ZIP_TABLE = (
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[2-578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
-    '860' => '(?:8(?:5(?:3[013469]|1\d|8[014-8]|7[057]|6[5-8]|5[0-24-8]|4[01357]|0[13-9]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
+    '860' => '(?:8(?:5(?:3[013469]|1\d|8[014-8]|7[057]|0[1-9]|6[5-8]|5[0-24-8]|4[01357]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[23568])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[2-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|85(?:01|14|38|2[089])|2(?:29[35-7]|[14]92)|6[13]95|7292))',
-    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|1[06]|9[34]|0[12]|2[01])|5(?:[12]0|[58]5|0[2458]|7[01])))',
+    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|1[06]|9[34]|0[12]|2[01])|5(?:[58]5|10|0[2458]|7[01])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
     '864' => '(?:8(?:6(?:11|86)|501))',
     '865' => '(?:(?:85(?:[01]1|33|77|5[05])|019[23]))',
@@ -896,7 +896,7 @@ our %ZIP_TABLE = (
     '937' => '(?:8(?:5(?:[58]5|03|11|6[67])|6(?:01|60|78)))',
     '938' => '(?:(?:8(?:6(?:1[0-3]|0[12])|5(?:[58]5|0[25]))|029[23]))',
     '939' => '(?:(?:8(?:5(?:21|67|0[127]|[58][058]|1[0157]|7[12])|6(?:01|50|3[06]|4[02]|1[01]))|1(?:39[2-8]|89[23578]|59[2356]|69[2-48]|19[23]|99[78]|492)|0(?:29[2-6]|79[2358]|39[258]|[15]92|693)|2(?:29[23578]|39[238]|69[24]|192|595|798)|3593))',
-    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|392|595)|029[2-8]|119[3-68]))',
+    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|8[58]|5[125]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|319[578]))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[17-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|319[578]))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|3[01356]|8[0156]|0[2-478]|5[0-6])|6(?:01|40|78|8[056]|5[05]|3[023]|2[029]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
